@@ -580,7 +580,7 @@ LdapSearchDialog::LdapSearchDialog(QWidget *parent)
     d->mResultView->verticalHeader()->hide();
     d->mResultView->setSortingEnabled(true);
     d->mResultView->horizontalHeader()->setSortIndicatorShown(true);
-    connect(d->mResultView, QOverload<const QModelIndex &>::of(&QTableView::clicked), this, [this]() {
+    connect(d->mResultView, qOverload<const QModelIndex &>(&QTableView::clicked), this, [this]() {
         d->slotSelectionChanged();
     });
     topLayout->addWidget(d->mResultView);
